@@ -7,7 +7,7 @@ import sys
 # default app settings
 # @see: http://www.muhuk.com/2010/01/developing-reusable-django-apps-app-settings/
 
-CRONJOBS = getattr(settings, 'CRONJOBS')
+CRONJOBS = getattr(settings, 'CRONJOBS', [])
 
 CRONTAB_EXECUTABLE = getattr(settings, 'CRONTAB_EXECUTABLE', '/usr/bin/crontab')
 
